@@ -1,15 +1,18 @@
 use utf8;
 use strict;
+use warnings;
+no warnings qw(uninitialized);
 
+#======================================================================
+package XML::Pastor::Builtin::boolean;
 use XML::Pastor::Builtin::Scalar;
 
+our @ISA = qw(XML::Pastor::Builtin::Scalar);
+
 use overload 
 	'bool'	=> \&boolify;
 	
-#======================================================================
-package XML::Pastor::Builtin::boolean;
-our @ISA = qw(XML::Pastor::Builtin::Scalar);
-
+	
 XML::Pastor::Builtin::boolean->XmlSchemaType( bless( {
                  'class' => 'XML::Pastor::Builtin::boolean',
                  'contentType' => 'simple',
@@ -30,8 +33,8 @@ XML::Pastor::Builtin::boolean->XmlSchemaType( bless( {
 #----------------------------------------------
 sub boolify {
 	my $self = shift;
-	my $val = $self->value();	
-		
+	my $val = $self->__value();	
+	
 	return 0 if ($val =~ /false/io);
 	return $val;	
 }
@@ -102,7 +105,7 @@ Note that there may be other bugs or limitations that the author is not aware of
 
 =head1 AUTHOR
 
-Ayhan Ulusoy <dev@ulusoy.name>
+Ayhan Ulusoy <dev(at)ulusoy(dot)name>
 
 
 =head1 COPYRIGHT
