@@ -1,5 +1,7 @@
 use utf8;
 use strict;
+use warnings;
+no warnings qw(uninitialized);
 
 
 #======================================================================
@@ -155,7 +157,7 @@ Note that there may be other bugs or limitations that the author is not aware of
 
 =head1 AUTHOR
 
-Ayhan Ulusoy <dev@ulusoy.name>
+Ayhan Ulusoy <dev(at)ulusoy(dot)name>
 
 
 =head1 COPYRIGHT
